#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_DAWSON_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_DAWSON_HPP_INCLUDED

#include <nt2/euler/include/functions/scalar/dawson.hpp>

#endif
